import { z } from 'zod';
export declare const Culture: z.ZodString;
export type Culture = z.infer<typeof Culture>;
export declare const LocalizedString: z.ZodTuple<[z.ZodString, z.ZodString], null>;
export type LocalizedString = z.infer<typeof LocalizedString>;
export declare const LocalizableString: z.ZodRecord<z.ZodString, z.ZodString>;
export type LocalizableString = z.infer<typeof LocalizableString>;
export declare const LocalizedStringSet: z.ZodTuple<[z.ZodString, z.ZodRecord<z.ZodString, z.ZodString>], null>;
export type LocalizedStringSet = z.infer<typeof LocalizedStringSet>;
export type StringSetDefinition = z.ZodObject<Record<string, z.ZodString>>;
export type StringSet = z.infer<StringSetDefinition>;
export declare function createLocalizableStringSet<T extends StringSetDefinition>(stringSet: T): z.ZodRecord<z.ZodString, T>;
export declare const SimpleStringSet: z.ZodObject<{
    name: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
}, {
    name: string;
}>;
export type SimpleStringSet = z.infer<typeof SimpleStringSet>;
export declare const SimpleLocalizableStringSet: z.ZodRecord<z.ZodString, z.ZodObject<{
    name: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
}, {
    name: string;
}>>;
export type SimpleLocalizableStringSet = z.infer<typeof SimpleLocalizableStringSet>;
export declare const ExtensibleSimpleStringSet: z.ZodObject<{
    name: z.ZodString;
}, "strip", z.ZodString, z.objectOutputType<{
    name: z.ZodString;
}, z.ZodString, "strip">, z.objectInputType<{
    name: z.ZodString;
}, z.ZodString, "strip">>;
export type ExtensibleSimpleStringSet = z.infer<typeof ExtensibleSimpleStringSet>;
export declare const ExtensibleSimpleLocalizableStringSet: z.ZodRecord<z.ZodString, z.ZodObject<{
    name: z.ZodString;
}, "strip", z.ZodString, z.objectOutputType<{
    name: z.ZodString;
}, z.ZodString, "strip">, z.objectInputType<{
    name: z.ZodString;
}, z.ZodString, "strip">>>;
export type ExtensibleSimpleLocalizableStringSet = Record<Culture, ExtensibleSimpleStringSet>;
export declare const StandardStringSet: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
    description: string;
}, {
    name: string;
    description: string;
}>;
export type StandardStringSet = z.infer<typeof StandardStringSet>;
export declare const StandardLocalizableStringSet: z.ZodRecord<z.ZodString, z.ZodObject<{
    name: z.ZodString;
    description: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
    description: string;
}, {
    name: string;
    description: string;
}>>;
export type StandardLocalizableStringSet = z.infer<typeof StandardLocalizableStringSet>;
export declare const ExtensibleStandardStringSet: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodString;
}, "strip", z.ZodString, z.objectOutputType<{
    name: z.ZodString;
    description: z.ZodString;
}, z.ZodString, "strip">, z.objectInputType<{
    name: z.ZodString;
    description: z.ZodString;
}, z.ZodString, "strip">>;
export type ExtensibleStandardStringSet = z.infer<typeof ExtensibleStandardStringSet>;
export declare const ExtensibleStandardLocalizableStringSet: z.ZodRecord<z.ZodString, z.ZodObject<{
    name: z.ZodString;
    description: z.ZodString;
}, "strip", z.ZodString, z.objectOutputType<{
    name: z.ZodString;
    description: z.ZodString;
}, z.ZodString, "strip">, z.objectInputType<{
    name: z.ZodString;
    description: z.ZodString;
}, z.ZodString, "strip">>>;
export type ExtensibleStandardLocalizableStringSet = Record<Culture, ExtensibleStandardStringSet>;
export declare enum MessageType {
    AccessDenied = "AccessDenied",
    ProcessError = "ProcessError",
    TechnicalIssue = "TechnicalIssue",
    UnknownResource = "UnknownResource",
    Warn = "Warn"
}
export declare const Message: z.ZodObject<{
    type: z.ZodNativeEnum<typeof MessageType>;
    code: z.ZodString;
    parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    issuer: z.ZodOptional<z.ZodString>;
    localizableString: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    localizedString: z.ZodOptional<z.ZodTuple<[z.ZodString, z.ZodString], null>>;
}, "strip", z.ZodTypeAny, {
    code: string;
    type: MessageType;
    parameters?: Record<string, string> | undefined;
    issuer?: string | undefined;
    localizableString?: Record<string, string> | undefined;
    localizedString?: [string, string] | undefined;
}, {
    code: string;
    type: MessageType;
    parameters?: Record<string, string> | undefined;
    issuer?: string | undefined;
    localizableString?: Record<string, string> | undefined;
    localizedString?: [string, string] | undefined;
}>;
export type Message = z.infer<typeof Message>;
