"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Message = exports.MessageType = exports.ExtensibleStandardLocalizableStringSet = exports.ExtensibleStandardStringSet = exports.StandardLocalizableStringSet = exports.StandardStringSet = exports.ExtensibleSimpleLocalizableStringSet = exports.ExtensibleSimpleStringSet = exports.SimpleLocalizableStringSet = exports.SimpleStringSet = exports.createLocalizableStringSet = exports.LocalizedStringSet = exports.LocalizableString = exports.LocalizedString = exports.Culture = void 0;
const zod_1 = require("zod");
exports.Culture = zod_1.z.string().regex(/^[a-z]{2}(-[A-Z]{2})?$/);
exports.LocalizedString = zod_1.z.tuple([exports.Culture, zod_1.z.string()]);
exports.LocalizableString = zod_1.z.record(exports.Culture, zod_1.z.string());
exports.LocalizedStringSet = zod_1.z.tuple([exports.Culture, zod_1.z.record(zod_1.z.string())]);
function createLocalizableStringSet(stringSet) {
    return zod_1.z.record(exports.Culture, stringSet);
}
exports.createLocalizableStringSet = createLocalizableStringSet;
exports.SimpleStringSet = zod_1.z.object({
    name: zod_1.z.string(),
});
exports.SimpleLocalizableStringSet = createLocalizableStringSet(exports.SimpleStringSet);
exports.ExtensibleSimpleStringSet = exports.SimpleStringSet.catchall(zod_1.z.string());
exports.ExtensibleSimpleLocalizableStringSet = createLocalizableStringSet(exports.ExtensibleSimpleStringSet);
exports.StandardStringSet = zod_1.z.object({
    name: zod_1.z.string(),
    description: zod_1.z.string(),
});
exports.StandardLocalizableStringSet = createLocalizableStringSet(exports.StandardStringSet);
exports.ExtensibleStandardStringSet = exports.StandardStringSet.catchall(zod_1.z.string());
exports.ExtensibleStandardLocalizableStringSet = createLocalizableStringSet(exports.ExtensibleStandardStringSet);
var MessageType;
(function (MessageType) {
    MessageType["AccessDenied"] = "AccessDenied";
    MessageType["ProcessError"] = "ProcessError";
    MessageType["TechnicalIssue"] = "TechnicalIssue";
    MessageType["UnknownResource"] = "UnknownResource";
    MessageType["Warn"] = "Warn";
})(MessageType || (exports.MessageType = MessageType = {}));
exports.Message = zod_1.z.object({
    type: zod_1.z.nativeEnum(MessageType),
    code: zod_1.z.string(),
    parameters: zod_1.z.record(zod_1.z.string()).optional(),
    issuer: zod_1.z.string().optional(),
    localizableString: exports.LocalizableString.optional(),
    localizedString: exports.LocalizedString.optional(),
});
