import { Message, MessageType } from '../i18n/definitions';
export declare abstract class Result<S> {
    protected constructor(warnings?: Message[]);
    warnings?: Message[];
    addWarnings(warnings?: Message[]): this;
    static encase<X>(inner: () => X, failure: (reason: unknown) => Failure): Result<X>;
    static sequence<X>(list: Result<X>[]): Result<X[]>;
    static sequenceWithAllFailures<X>(list: Result<X>[]): Result<X[]>;
    static sequenceWithoutFailure<X>(list: Result<X>[]): Success<X[]>;
    static first<X>(list: X[], condition: (value: X) => Result<boolean>): Result<X | undefined>;
    abstract isFailure(): boolean;
    abstract isSuccess(): boolean;
    observe(f: (result: Result<S>) => void): Result<S>;
    abstract mapSuccess<S2>(onSuccess: (value: S) => Success<S2>): Result<S2>;
    abstract mapFailure(onFailure: (errors: Message[]) => Failure): Result<S>;
    abstract mapBoth<S2>(onFailure: (errors: Message[]) => Failure, onSuccess: (value: S) => Success<S2>): Result<S2>;
    abstract chainSuccess<S2>(next: (value: S) => Result<S2>): Result<S2>;
    abstract chainFailure<S2>(next: (errors: Message[]) => Result<S2>): Result<S | S2>;
    abstract chainBoth<S2, S3>(onFailure: (errors: Message[]) => Result<S2>, onSuccess: (value: S) => Result<S3>): Result<S2 | S3>;
    abstract downgradeErrorsToWarnings(withErrorFlag?: boolean): Success<S | boolean>;
    abstract getAllMessages(): Message[];
}
export declare class Success<S> extends Result<S> {
    readonly value: S;
    constructor(value: S, warnings?: Message[]);
    isFailure(): boolean;
    isSuccess(): boolean;
    mapSuccess<S2>(onSuccess: (value: S) => Success<S2>): Result<S2>;
    mapFailure(onFailure: (errors: Message[]) => Failure): Result<S>;
    mapBoth<S2>(onFailure: (errors: Message[]) => Failure, onSuccess: (value: S) => Success<S2>): Result<S2>;
    chainSuccess<S2>(next: (value: S) => Result<S2>): Result<S2>;
    chainFailure<S2>(next: (errors: Message[]) => Result<S2>): Result<S | S2>;
    chainBoth<S2, S3>(onFailure: (errors: Message[]) => Result<S2>, onSuccess: (value: S) => Result<S3>): Result<S2 | S3>;
    downgradeErrorsToWarnings(withErrorFlag?: boolean): Success<S | boolean>;
    getAllMessages(): Message[];
}
export declare class Failure<S = never> extends Result<S> {
    readonly errors: Message[];
    constructor(errors: Message[], warnings?: Message[]);
    static single(code: string, parameters?: Record<string, string>, issuer?: string, type?: MessageType): Failure;
    isFailure(): boolean;
    isSuccess(): boolean;
    mapSuccess<S2>(_: (value: S) => Success<S2>): Result<S2>;
    mapFailure(onFailure: (errors: Message[]) => Failure): Result<S>;
    mapBoth<S2>(onFailure: (errors: Message[]) => Failure, onSuccess: (value: S) => Success<S2>): Result<S2>;
    chainSuccess<S2>(next: (value: S) => Result<S2>): Result<S2>;
    chainFailure<S2>(next: (errors: Message[]) => Result<S2>): Result<S | S2>;
    chainBoth<S2, S3>(onFailure: (errors: Message[]) => Result<S2>, onSuccess: (value: S) => Result<S3>): Result<S2 | S3>;
    downgradeErrorsToWarnings(withErrorFlag?: boolean): Success<S | boolean>;
    getAllMessages(): Message[];
}
